package com.sybotan.android.demo.viewmodel

import android.app.Activity.RESULT_OK
import android.app.Application
import androidx.lifecycle.viewModelScope
import cn.sagacloud.android.cadengine.types.*
import com.framework.mvvm.model.db.entity.*
import com.framework.mvvm.model.db.entity.task.Infos
import com.framework.mvvm.model.repository.AdmRepository
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import com.sybotan.android.demo.activities.BaseActivity
import com.sybotan.android.demo.retrofit.BaseViewModelInterface
import kotlinx.coroutines.launch
import org.kodein.di.DI
import org.kodein.di.DIAware
import org.kodein.di.android.x.closestDI
import org.kodein.di.instance
import kotlin.collections.HashMap


/**
 * Created by lihao.
 * Date: 2021/6/9
 * 空间详情
 */
class SpaceDetailVM(
    app: Application,
    b: BaseViewModelInterface?, activity: BaseActivity?, //建筑id
    private val buildingId: String, //楼层id
    private val floorId: String,
    private val projectId: String
) : BaseViewModel(app, b, activity), DIAware {
    private val gson = Gson()

    override val di: DI by closestDI()
    private val repo: AdmRepository by instance()

    /**
     * SPACE_INFO 静态信息点配置
     * SPACE_INFOS 对象静态信息的值
     */
    fun getInfosConfig(spaceId: String) {
        viewModelScope.launch {
            val infosConfig = repo.getInfosConfigByObjType("space")
            val strInfos = infosConfig[0].strInfos
            val infoList = gson.fromJson<List<Infos>>(
                strInfos,
                object : TypeToken<List<Infos?>?>() {}.type
            )
            val spaceObject = repo.getObject(spaceId)
            val infos = gson.fromJson(spaceObject!!.strInfos, HashMap::class.java)
            mEmitter.SendDircetive(SPACE_INFOS, infos)
            mEmitter.SendDircetive(SPACE_INFO, infoList)
        }
    }

    /**
     * 更新空间信息点值
     */
    fun refreshObject(space: TunableSpace, hashMap: HashMap<String, Any>) {
        viewModelScope.launch {
            val spaceObj = repo.getObject(space.id!!)
            spaceObj!!.strInfos = gson.toJson(hashMap)
            spaceObj.state = "1"
            repo.insObject(spaceObj)
            mActivity.setResult(RESULT_OK)
            mActivity.finish()
        }
    }


    companion object {
        //静态信息点配置
        const val SPACE_INFO = "SPACE_INFO"

        //对象静态信息点值
        const val SPACE_INFOS = "SPACE_INFOS"
    }

}